@@ -1,12 +1,7 @@
 # -*- coding: UTF-8 -*-
-import copy
 from ctypes import *
-import time
 import sys
 from commFunction import *
-mosResult = copy.deepcopy(constMosResult)
-import os
-import xlwt
 
 params = [1, 16000, 16, 99, 1, 16000, 16, 99, 1, 1, 0.2, 1, 0, 1, 0, 2, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
           -1, -1]  # for WB 16K sample rate
@@ -40,11 +35,11 @@ def VQTMSGfunc(msg):
         mosFailedFlag = True
     else:
         if 'POLQA:' in cs:
-            mosResult['mos'] = cs.split('POLQA:')[1].strip()
+            global_result.mosResult['mos'] = cs.split('POLQA:')[1].strip()
         if 'Speech Level Gain:' in cs:
-            mosResult['Speech Level Gain'] = cs.split('Speech Level Gain:')[1].strip()
+            global_result.mosResult['Speech Level Gain'] = cs.split('Speech Level Gain:')[1].strip()
         if 'Noise Level Gain:' in cs:
-            mosResult['Noise Level Gain'] = cs.split('Noise Level Gain:')[1].strip()
+            global_result.mosResult['Noise Level Gain'] = cs.split('Noise Level Gain:')[1].strip()
 
 
 def startvqt(srcFile=None, degFile=None, samplerate=48000):
@@ -57,7 +52,6 @@ def startvqt(srcFile=None, degFile=None, samplerate=48000):
     params = (c_float * len(params))(*params)
     if connect_flag == False:
         vip = getip()
-        print(vip)
         try:
             VQTdll.ConnectPort(c_char_p(vip.encode('utf_8')), 6666)
             while connect_flag == False:
@@ -103,5 +97,5 @@ if __name__ == '__main__':
     output3 = r'E:\02_POLQA_RESULT\testDstFiles\123.pcm'
     startvqt(srcFile=input, degFile=output3,
              samplerate=16000)
-    print(mosResult['mos'])
+    print(global_result.mosResult['mos'])
     VQTdll.Disconnect()
